@@ -26,10 +26,17 @@ capture_first_vec <- structure(function # Capture first match in each character
 ### if TRUE (default), stop with an error if any subject does not
 ### match; otherwise subjects that do not match are reported as
 ### missing/NA rows of the result.
-  engine=getOption("nc.engine", "PCRE")
+  engine=getOption("nc.engine", "PCRE"),
 ### character string, one of PCRE, ICU, RE2
+  type.convert=getOption("nc.type.convert", FALSE)
+### Default conversion function, which will be used on each capture
+### group, unless a specific conversion is specified for that
+### group. If TRUE, use utils::type.convert; if FALSE, use
+### base::identity; otherwise must be a function of at least one
+### argument (character), returning an atomic vector of the same
+### length.
 ){
-  L <- subject_var_args(...)
+  L <- subject_var_args(..., type.convert=type.convert)
   subject.vec <- L[["subject"]]
   stop_for_engine(engine)
   ##alias<< nc
@@ -111,5 +118,51 @@ capture_first_vec <- structure(function # Capture first match in each character
     chr.pos.vec)
   nc::capture_first_vec(na.vec, range.pattern, nomatch.error=FALSE)
 
+  ## another subject from https://adventofcode.com/2024/day/14
+  ## type.convert=TRUE means to use utils::type.convert as default
+  ## conversion function
+  pvxy.subject <- c("p=0,4 v=3,-3","p=6,3 v=-1,-3")
+  nc::capture_first_vec(
+    pvxy.subject,
+    "p=",
+    px="[0-9]",
+    ",",
+    py="[0-9]",
+    " v=",
+    vx="[-0-9]+",
+    ",",
+    vy="[-0-9]+",
+    type.convert=TRUE)
+
+  ## to do the same as above but with less repetition:
+  g <- function(prefix,suffix)nc::group(
+    name=paste0(prefix,suffix),
+    "[-0-9]+")
+  xy <- function(prefix)list(
+    prefix,
+    "=",
+    g(prefix,"x"),
+    ",",
+    g(prefix,"y"))
+  nc::capture_first_vec(
+    pvxy.subject,
+    xy("p"),
+    " ",
+    xy("v"),
+    type.convert=TRUE)
+
+  ## or use a sub-pattern list without type.convert arg:
+  ipat <- list("[-0-9]+", as.integer)
+  nc::capture_first_vec(
+    pvxy.subject,
+    "p=",
+    px=ipat,
+    ",",
+    py=ipat,
+    " v=",
+    vx=ipat,
+    ",",
+    vy=ipat)
+
 })
 
